Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/infra/properties/org.eclipse.papyrus.infra.properties/src-gen/org/eclipse/papyrus/infra/properties/contexts/Section.java')
-rw-r--r--plugins/infra/properties/org.eclipse.papyrus.infra.properties/src-gen/org/eclipse/papyrus/infra/properties/contexts/Section.java128
1 files changed, 58 insertions, 70 deletions
diff --git a/plugins/infra/properties/org.eclipse.papyrus.infra.properties/src-gen/org/eclipse/papyrus/infra/properties/contexts/Section.java b/plugins/infra/properties/org.eclipse.papyrus.infra.properties/src-gen/org/eclipse/papyrus/infra/properties/contexts/Section.java
index 4dde5973ad8..97228b35247 100644
--- a/plugins/infra/properties/org.eclipse.papyrus.infra.properties/src-gen/org/eclipse/papyrus/infra/properties/contexts/Section.java
+++ b/plugins/infra/properties/org.eclipse.papyrus.infra.properties/src-gen/org/eclipse/papyrus/infra/properties/contexts/Section.java
@@ -1,5 +1,5 @@
/*****************************************************************************
- * Copyright (c) 2011 CEA LIST.
+ * Copyright (c) 2011, 2021 CEA LIST, Christian W. Damus, and others.
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License 2.0
@@ -10,10 +10,11 @@
*
* Contributors:
* CEA LIST - Initial API and implementation
+ * Christian W. Damus - bug 573986
*****************************************************************************/
package org.eclipse.papyrus.infra.properties.contexts;
-import org.eclipse.papyrus.infra.constraints.DisplayUnit;
+import org.eclipse.emf.common.util.EList;
import org.eclipse.papyrus.infra.properties.ui.CompositeWidget;
/**
@@ -25,129 +26,116 @@ import org.eclipse.papyrus.infra.properties.ui.CompositeWidget;
* The following features are supported:
* </p>
* <ul>
* <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getName <em>Name</em>}</li>
* <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getTab <em>Tab</em>}</li>
* <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getSectionFile <em>Section File</em>}</li>
* <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getWidget <em>Widget</em>}</li>
* </ul>
*
* @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection()
* @model
* @generated
*/
-public interface Section extends DisplayUnit {
+public interface Section extends AbstractSection {
/**
- * Returns the value of the '<em><b>Name</b></em>' attribute.
+ * Returns the value of the '<em><b>Section File</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Name</em>' attribute isn't clear, there really should be more of a description here...
+ * If the meaning of the '<em>Section File</em>' attribute isn't clear, there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Name</em>' attribute.
- * @see #setName(String)
- * @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_Name()
+ * @return the value of the '<em>Section File</em>' attribute.
+ * @see #setSectionFile(String)
+ * @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_SectionFile()
* @model required="true"
* @generated
*/
- String getName();
+ String getSectionFile();
/**
- * Sets the value of the '{@link org.eclipse.papyrus.infra.properties.contexts.Section#getName <em>Name</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.papyrus.infra.properties.contexts.Section#getSectionFile <em>Section File</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- *
- * @param value
- * the new value of the '<em>Name</em>' attribute.
- * @see #getName()
+ * @param value the new value of the '<em>Section File</em>' attribute.
+ * @see #getSectionFile()
* @generated
*/
- void setName(String value);
+ void setSectionFile(String value);
/**
- * Returns the value of the '<em><b>Tab</b></em>' container reference.
- * It is bidirectional and its opposite is '{@link org.eclipse.papyrus.infra.properties.contexts.Tab#getSections <em>Sections</em>}'.
+ * Returns the value of the '<em><b>Widget</b></em>' reference.
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Tab</em>' container reference isn't clear, there really should be more of a description here...
+ * If the meaning of the '<em>Widget</em>' reference isn't clear, there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Tab</em>' container reference.
- * @see #setTab(Tab)
- * @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_Tab()
- * @see org.eclipse.papyrus.infra.properties.contexts.Tab#getSections
- * @model opposite="sections" required="true" transient="false"
+ * @return the value of the '<em>Widget</em>' reference.
+ * @see #setWidget(CompositeWidget)
+ * @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_Widget()
+ * @model required="true"
* @generated
*/
- Tab getTab();
+ CompositeWidget getWidget();
/**
- * Sets the value of the '{@link org.eclipse.papyrus.infra.properties.contexts.Section#getTab <em>Tab</em>}' container reference.
+ * Sets the value of the '{@link org.eclipse.papyrus.infra.properties.contexts.Section#getWidget <em>Widget</em>}' reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- *
- * @param value
- * the new value of the '<em>Tab</em>' container reference.
- * @see #getTab()
+ * @param value the new value of the '<em>Widget</em>' reference.
+ * @see #getWidget()
* @generated
*/
- void setTab(Tab value);
+ void setWidget(CompositeWidget value);
/**
- * Returns the value of the '<em><b>Section File</b></em>' attribute.
+ * Returns the value of the '<em><b>Views</b></em>' reference list.
+ * The list contents are of type {@link org.eclipse.papyrus.infra.properties.contexts.View}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Section File</em>' attribute isn't clear, there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
*
* @return the value of the '<em>Section File</em>' attribute.
* @see #setSectionFile(String)
* @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_SectionFile()
* @model required="true"
* @generated
*/
- String getSectionFile();
+ EList<View> getViews();
/**
- * Sets the value of the '{@link org.eclipse.papyrus.infra.properties.contexts.Section#getSectionFile <em>Section File</em>}' attribute.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- *
- * @param value
- * the new value of the '<em>Section File</em>' attribute.
- * @see #getSectionFile()
- * @generated
- */
- void setSectionFile(String value);
-
- /**
- * Returns the value of the '<em><b>Widget</b></em>' reference.
+ * Returns the value of the '<em><b>Owner</b></em>' reference.
+ * It is bidirectional and its opposite is '{@link org.eclipse.papyrus.infra.properties.contexts.Tab#getSections <em>Sections</em>}'.
+ * <p>
+ * This feature subsets the following features:
+ * </p>
+ * <ul>
+ * <li>'{@link org.eclipse.papyrus.infra.properties.contexts.AbstractSection#getTab() <em>Tab</em>}'</li>
+ * </ul>
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Widget</em>' reference isn't clear, there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
*
* @return the value of the '<em>Widget</em>' reference.
* @see #setWidget(CompositeWidget)
* @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_Widget()
* @model required="true"
* @generated
*/
- CompositeWidget getWidget();
+ Tab getOwner();
/**
* Sets the value of the '{@link org.eclipse.papyrus.infra.properties.contexts.Section#getWidget <em>Widget</em>}' reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
*
* @param value
* the new value of the '<em>Widget</em>' reference.
* @see #getWidget()
* @generated
*/
- void setWidget(CompositeWidget value);
+ void setOwner(Tab value);
} // Section

Back to the top
@@ -25,129 +26,116 @@ import org.eclipse.papyrus.infra.properties.ui.CompositeWidget;
* </p>
* <ul>
- * <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getName <em>Name</em>}</li>
- * <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getTab <em>Tab</em>}</li>
- * <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getSectionFile <em>Section File</em>}</li>
- * <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getWidget <em>Widget</em>}</li>
+ * <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getSectionFile <em>Section File</em>}</li>
+ * <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getWidget <em>Widget</em>}</li>
+ * <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getViews <em>Views</em>}</li>
+ * <li>{@link org.eclipse.papyrus.infra.properties.contexts.Section#getOwner <em>Owner</em>}</li>
* </ul>
*
@@ -25,129 +26,116 @@ import org.eclipse.papyrus.infra.properties.ui.CompositeWidget;
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Section File</em>' attribute isn't clear, there really should be more of a description here...
+ * If the meaning of the '<em>Views</em>' reference list isn't clear,
+ * there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
@@ -25,129 +26,116 @@ import org.eclipse.papyrus.infra.properties.ui.CompositeWidget;
* </p>
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Section File</em>' attribute.
- * @see #setSectionFile(String)
- * @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_SectionFile()
- * @model required="true"
+ * @return the value of the '<em>Views</em>' reference list.
+ * @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_Views()
+ * @model transient="true" changeable="false" volatile="true" derived="true" ordered="false"
* @generated
*/
@@ -25,129 +26,116 @@ import org.eclipse.papyrus.infra.properties.ui.CompositeWidget;
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Widget</em>' reference isn't clear, there really should be more of a description here...
+ * If the meaning of the '<em>Owner</em>' reference isn't clear,
+ * there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
@@ -25,129 +26,116 @@ import org.eclipse.papyrus.infra.properties.ui.CompositeWidget;
* </p>
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Widget</em>' reference.
- * @see #setWidget(CompositeWidget)
- * @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_Widget()
- * @model required="true"
+ * @return the value of the '<em>Owner</em>' reference.
+ * @see #setOwner(Tab)
+ * @see org.eclipse.papyrus.infra.properties.contexts.ContextsPackage#getSection_Owner()
+ * @see org.eclipse.papyrus.infra.properties.contexts.Tab#getSections
+ * @model opposite="sections" required="true" transient="true" volatile="true" derived="true"
+ * annotation="subsets"
* @generated
*/
@@ -25,129 +26,116 @@ import org.eclipse.papyrus.infra.properties.ui.CompositeWidget;
/**
- * Sets the value of the '{@link org.eclipse.papyrus.infra.properties.contexts.Section#getWidget <em>Widget</em>}' reference.
+ * Sets the value of the '{@link org.eclipse.papyrus.infra.properties.contexts.Section#getOwner <em>Owner</em>}' reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -25,129 +26,116 @@ import org.eclipse.papyrus.infra.properties.ui.CompositeWidget;
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- *
- * @param value
- * the new value of the '<em>Widget</em>' reference.
- * @see #getWidget()
+ * @param value the new value of the '<em>Owner</em>' reference.
+ * @see #getOwner()
* @generated
*/